# Dlubal RSTAB8
# 2020 foo.li systeme + software

$packageName  = 'dlubal-rstab8'
$fileType     = 'exe'
$version      = '8.24.01'
$shortver     = '8.24'
$release      = '156507'
$ProductName  = 'Dlubal RSTAB ' + $shortver + '*'
$url          = '\\unxfsv001\software\frommelt-zimmerei\dlubal\rstab\v8x\RSTAB' + $version + '_64bit.exe'

$arguments = @{}

# parameters
# /licensefile:<author.ini with path> /force
# config is mandatory
if (!($env:PROCESSOR_ARCHITECTURE -eq 'AMD64')) {
    throw 'RSTAB only supports x64 platforms'
}

# Now we can use the $env:chocolateyPackageParameters inside the Chocolatey package
$packageParameters = $env:chocolateyPackageParameters

# Default the values
$licensefile = ''

# Now parse the packageParameters using good old regular expression
if ($packageParameters) {
    $match_pattern = "\/(?<option>([a-zA-Z]+)):(?<value>([`"'])?([a-zA-Z0-9- _\\:\.]+)([`"'])?)|\/(?<option>([a-zA-Z]+))"
    $option_name = 'option'
    $value_name = 'value'

    if ($packageParameters -match $match_pattern ){
        $results = $packageParameters | Select-String $match_pattern -AllMatches
        $results.matches | % {
          $arguments.Add(
              $_.Groups[$option_name].Value.Trim(),
              $_.Groups[$value_name].Value.Trim())
      }
    }
    else
    {
        Throw "Package Parameters were found but were invalid (REGEX Failure)"
    }
    if ($arguments.ContainsKey("licensefile")) {
        Write-Host "licensefile argument found"
        $licensefile = $arguments["licensefile"]
        Write-Host "Value: " $licensefile
    }
    if ($arguments.ContainsKey("force")) {
        Write-Host "force argument found"
        $force = $true
    }
} else {
    Write-Debug "No Package Parameters Passed in"
}

if (!($licensefile)){
    Write-Warning 'no answerfile given. use the /licensefile:[path-to-author.ini] parameter (path without quotes)'
    throw $_.Exception
}

if (!(Test-Path $licensefile)){
    Write-Warning 'cannot access AUTHOR.INI file. please check the path.'
    throw $_.Exception
}

try {
   $silentArgs = '-L 1031 -passive AUTHORIZATION_FILE_PATH=' + $licensefile

   $app = Get-ItemProperty -Path @( 'HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                      'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*')`
                             -ErrorAction:SilentlyContinue `
                             | Where-Object { $_.DisplayName -like $productName }
   if (($app -and ($app.DisplayVersion -ge $version.release)) -and (!($force -eq $true))) {
       Write-Output $(
       'RSTAB8 ' + $version + ' is already installed. ' +
       'No need to download and install again. Otherwise, use the /force parameter'
       )
   } else {
       Write-Host 'starting setup...this may take some time'
       Write-Host 'url: ' $url
       Write-Host 'Args: ' $silentArgs
       (Start-Process -FilePath "$url" -ArgumentList "$silentArgs" -Verb runAs -Wait -Passthru).ExitCode
       If ($LASTEXITCODE -ne 0) {
           throw 'kacke'
       }
   }
} catch {
    throw $_.Exception
}
